@@ -152,7 +152,7 @@ around app_build => sub ( $orig, $self ) {
         my $res = try {
             P->file->chdir( $build_dir . 'nginx-' . $self->nginx_ver );
 
-            P->sys->system(
+            P->pm->run_check(
                 join q[ ],    #
                 './configure',
                 '--prefix=' . $self->alien_dir,
@@ -170,9 +170,9 @@ around app_build => sub ( $orig, $self ) {
                 map { '--add-module=' . $build_dir . $module->{$_}->{path} } grep { $module->{$_}->{enabled} } keys $module->%*,
             );
 
-            P->sys->system( 'make', q[-j] . P->sys->cpus_num );
+            P->pm->run_check( 'make', q[-j] . P->sys->cpus_num );
 
-            P->sys->system(qw[make install]);
+            P->pm->run_check(qw[make install]);
 
             return 1;
         }
@@ -207,12 +207,12 @@ around app_test => sub ( $orig, $self ) {
 
     $self->generate_alien_cfg;
 
-    my $res = P->capture->sys( $self->alien_bin_path, '-t', '-c', $self->alien_cfg_path );
+    my $out = P->pm->run_capture( $self->alien_bin_path, '-t', '-c', $self->alien_cfg_path );
 
-    if ( $res =~ /test\hfailed/sm ) {
+    say $out;
+
+    if ( $out =~ /test\hfailed/sm ) {
         say 'FAILED';
-
-        say $res;
     }
     else {
         say 'OK';
